/***************************************************************************
 *   Copyright (C) 2004 by bysk                                           *
 *   buysk@pf.pl                                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef WEATHER_H
#define WEATHER_H

#include <qobject.h>
#include <qlistview.h>
#include <qtextcodec.h>
#include <qprogressbar.h>
#include <qtimer.h>
#include <qhbuttongroup.h>

#include "config_file.h"
#include "userbox.h"
#include "misc.h"

#include "weather_parser.h"

class SearchIDLocation : public QDialog
{
	Q_OBJECT

	private:
		HttpClient httpclient;
		QTextCodec* decoder;		
		QString strPage;
		WeatherParser parser;
		
		QString locName;
		int cfPos;
	
	protected:
		const QStringList& weatherConfigFiles;
		QStringList names, codes;
		
		void encodeUrl(QString& url, const QString& enc);
		bool findID(QString loc_name, int config_pos);

	public:
		SearchIDLocation(ConfigFile* cf, const QStringList& wCfFiles,
                         QWidget* parent, QString wTitle);
		~SearchIDLocation();
		
	public slots:
		virtual void downloadingFinished();
		virtual void downloadingError() { }
		virtual void downloadingRedirected(QString link);
};

/**
	WeatherCodeDialog
**/
class WeatherCodeDialog : public SearchIDLocation
{
	Q_OBJECT
	
	private:
		QListViewItem* listItem;
		ConfigFile* moduleConfig;
		const QStringList& weatherConfigNames;
		
		QComboBox* c_config;
		QLineEdit* e_id;
		QLineEdit* e_name;
		QListView* lv_search;
		QPushButton* b_search;
		QProgressBar* p_linking;
		QPushButton* b_ok;
		QPushButton* b_cancel;
		
		QTimer* timer;
		
		static int config_pos;
		
	public:
		WeatherCodeDialog(const QString& altNick, QListViewItem* item, ConfigFile* cf,
			const QStringList& wCfFiles, const QStringList& wCfNames, int actual, QWidget* parent = 0);
		~WeatherCodeDialog();
		
		void downloadingFinished();
		void downloadingError();
		void downloadingRedirected(QString link);
		
	public slots:
		void okButton();
		void searchButton();
		void downloadingProgress();
		void searchSelChanged();
};

/**
	ShowForecastDialog
**/
class ShowForecastDialog : public QDialog
{
	Q_OBJECT
	
	private:
		QString loc_id;
		ConfigFile* moduleConfig;
		ConfigFile* wConfig;
		QString iconpath;
		Forecast forecast;
		QString locName;
		
		QVBoxLayout* vlayout;
		QLabel* l_header;
		QLabel* e_message;
		QHButtonGroup* btn_box;
		QProgressBar* p_linking;
		QTextCodec* decoder;
		QTimer* timer;
		
		HttpClient httpclient;	

		QString strPage;
		WeatherParser parser;
		
	private slots:
		void downloadingFinished();
		void downloadingError();
		void downloadingProgress();
		void dayClicked(int id);
		
	public:
		ShowForecastDialog(const QString& uin, ConfigFile* cf, QWidget* parent = 0);
		~ShowForecastDialog();
};

/**
	Weather
**/
class Weather : public QObject
{
	Q_OBJECT
	
	private:
		ConfigFile* moduleConfig;
		QStringList weatherConfigFiles;
		QStringList weatherConfigNames;
		
		int menuMyWeather;
	
	private slots:
		void PopupMenuCreate();
		void ShowWeather();
		void ShowMyWeather();
		void CreateConfigDialog();
		void ApplyConfigDialog();
		void EditLocation();
		
	public:
		Weather();
		~Weather();
};

#endif
